Title: [116646] trunk/Source/WebKit2
Revision
116646
Author
kent.han...@nokia.com
Date
2012-05-10 08:12:36 -0700 (Thu, 10 May 2012)

Log Message

[Qt] Rename QDeclarative* to QQml*
https://bugs.webkit.org/show_bug.cgi?id=86089

Reviewed by Simon Hausmann.

The QtDeclarative module was deprecated in favor of QtQml.

* Target.pri:
* UIProcess/API/qt/qquickwebview.cpp:
(QQuickWebViewPrivate::_q_onReceivedResponseFromDownload):
(QQuickWebViewExperimental::alertDialog):
(QQuickWebViewExperimental::setAlertDialog):
(QQuickWebViewExperimental::confirmDialog):
(QQuickWebViewExperimental::setConfirmDialog):
(QQuickWebViewExperimental::promptDialog):
(QQuickWebViewExperimental::setPromptDialog):
(QQuickWebViewExperimental::authenticationDialog):
(QQuickWebViewExperimental::setAuthenticationDialog):
(QQuickWebViewExperimental::proxyAuthenticationDialog):
(QQuickWebViewExperimental::setProxyAuthenticationDialog):
(QQuickWebViewExperimental::certificateVerificationDialog):
(QQuickWebViewExperimental::setCertificateVerificationDialog):
(QQuickWebViewExperimental::itemSelector):
(QQuickWebViewExperimental::setItemSelector):
(QQuickWebViewExperimental::filePicker):
(QQuickWebViewExperimental::setFilePicker):
(QQuickWebViewExperimental::databaseQuotaDialog):
(QQuickWebViewExperimental::setDatabaseQuotaDialog):
(QQuickWebViewExperimental::schemeDelegates_At):
(QQuickWebViewExperimental::schemeDelegates_Append):
(QQuickWebViewExperimental::schemeDelegates_Count):
(QQuickWebViewExperimental::schemeDelegates_Clear):
(QQuickWebViewExperimental::schemeDelegates):
* UIProcess/API/qt/qquickwebview_p.h:
* UIProcess/API/qt/qquickwebview_p_p.h:
(QQuickWebViewPrivate):
* UIProcess/API/qt/qwebiconimageprovider.cpp:
(QWebIconImageProvider::QWebIconImageProvider):
* UIProcess/API/qt/qwebiconimageprovider_p.h:
* UIProcess/API/qt/qwebviewportinfo_p.h:
* UIProcess/API/qt/tests/tests.pri:
* UIProcess/qt/QtDialogRunner.h:
(QtDialogRunner):
* UIProcess/qt/WebPopupMenuProxyQt.h:
(WebPopupMenuProxyQt):

Modified Paths

Diff

Modified: trunk/Source/WebKit2/ChangeLog (116645 => 116646)


--- trunk/Source/WebKit2/ChangeLog	2012-05-10 15:10:11 UTC (rev 116645)
+++ trunk/Source/WebKit2/ChangeLog	2012-05-10 15:12:36 UTC (rev 116646)
@@ -1,3 +1,51 @@
+2012-05-10  Kent Hansen  <kent.han...@nokia.com>
+
+        [Qt] Rename QDeclarative* to QQml*
+        https://bugs.webkit.org/show_bug.cgi?id=86089
+
+        Reviewed by Simon Hausmann.
+
+        The QtDeclarative module was deprecated in favor of QtQml.
+
+        * Target.pri:
+        * UIProcess/API/qt/qquickwebview.cpp:
+        (QQuickWebViewPrivate::_q_onReceivedResponseFromDownload):
+        (QQuickWebViewExperimental::alertDialog):
+        (QQuickWebViewExperimental::setAlertDialog):
+        (QQuickWebViewExperimental::confirmDialog):
+        (QQuickWebViewExperimental::setConfirmDialog):
+        (QQuickWebViewExperimental::promptDialog):
+        (QQuickWebViewExperimental::setPromptDialog):
+        (QQuickWebViewExperimental::authenticationDialog):
+        (QQuickWebViewExperimental::setAuthenticationDialog):
+        (QQuickWebViewExperimental::proxyAuthenticationDialog):
+        (QQuickWebViewExperimental::setProxyAuthenticationDialog):
+        (QQuickWebViewExperimental::certificateVerificationDialog):
+        (QQuickWebViewExperimental::setCertificateVerificationDialog):
+        (QQuickWebViewExperimental::itemSelector):
+        (QQuickWebViewExperimental::setItemSelector):
+        (QQuickWebViewExperimental::filePicker):
+        (QQuickWebViewExperimental::setFilePicker):
+        (QQuickWebViewExperimental::databaseQuotaDialog):
+        (QQuickWebViewExperimental::setDatabaseQuotaDialog):
+        (QQuickWebViewExperimental::schemeDelegates_At):
+        (QQuickWebViewExperimental::schemeDelegates_Append):
+        (QQuickWebViewExperimental::schemeDelegates_Count):
+        (QQuickWebViewExperimental::schemeDelegates_Clear):
+        (QQuickWebViewExperimental::schemeDelegates):
+        * UIProcess/API/qt/qquickwebview_p.h:
+        * UIProcess/API/qt/qquickwebview_p_p.h:
+        (QQuickWebViewPrivate):
+        * UIProcess/API/qt/qwebiconimageprovider.cpp:
+        (QWebIconImageProvider::QWebIconImageProvider):
+        * UIProcess/API/qt/qwebiconimageprovider_p.h:
+        * UIProcess/API/qt/qwebviewportinfo_p.h:
+        * UIProcess/API/qt/tests/tests.pri:
+        * UIProcess/qt/QtDialogRunner.h:
+        (QtDialogRunner):
+        * UIProcess/qt/WebPopupMenuProxyQt.h:
+        (WebPopupMenuProxyQt):
+
 2012-05-10  Jocelyn Turcotte  <jocelyn.turco...@nokia.com>
 
         [Qt] Fix sites with a viewport meta tag when devicePixelRatio isn't explicitely set on the WebView

Modified: trunk/Source/WebKit2/Target.pri (116645 => 116646)


--- trunk/Source/WebKit2/Target.pri	2012-05-10 15:10:11 UTC (rev 116645)
+++ trunk/Source/WebKit2/Target.pri	2012-05-10 15:12:36 UTC (rev 116646)
@@ -12,7 +12,7 @@
 include(WebKit2.pri)
 
 WEBKIT += wtf _javascript_core webcore
-QT += declarative quick quick-private
+QT += qml quick quick-private
 
 CONFIG += staticlib
 

Modified: trunk/Source/WebKit2/UIProcess/API/qt/qquickwebview.cpp (116645 => 116646)


--- trunk/Source/WebKit2/UIProcess/API/qt/qquickwebview.cpp	2012-05-10 15:10:11 UTC (rev 116645)
+++ trunk/Source/WebKit2/UIProcess/API/qt/qquickwebview.cpp	2012-05-10 15:12:36 UTC (rev 116646)
@@ -489,7 +489,7 @@
         return;
 
     Q_Q(QQuickWebView);
-    QDeclarativeEngine::setObjectOwnership(downloadItem, QDeclarativeEngine::_javascript_Ownership);
+    QQmlEngine::setObjectOwnership(downloadItem, QQmlEngine::_javascript_Ownership);
     emit q->experimental()->downloadRequested(downloadItem);
 }
 
@@ -1099,13 +1099,13 @@
     d->context->postMessageToNavigatorQtObject(d->webPageProxy.get(), message);
 }
 
-QDeclarativeComponent* QQuickWebViewExperimental::alertDialog() const
+QQmlComponent* QQuickWebViewExperimental::alertDialog() const
 {
     Q_D(const QQuickWebView);
     return d->alertDialog;
 }
 
-void QQuickWebViewExperimental::setAlertDialog(QDeclarativeComponent* alertDialog)
+void QQuickWebViewExperimental::setAlertDialog(QQmlComponent* alertDialog)
 {
     Q_D(QQuickWebView);
     if (d->alertDialog == alertDialog)
@@ -1114,13 +1114,13 @@
     emit alertDialogChanged();
 }
 
-QDeclarativeComponent* QQuickWebViewExperimental::confirmDialog() const
+QQmlComponent* QQuickWebViewExperimental::confirmDialog() const
 {
     Q_D(const QQuickWebView);
     return d->confirmDialog;
 }
 
-void QQuickWebViewExperimental::setConfirmDialog(QDeclarativeComponent* confirmDialog)
+void QQuickWebViewExperimental::setConfirmDialog(QQmlComponent* confirmDialog)
 {
     Q_D(QQuickWebView);
     if (d->confirmDialog == confirmDialog)
@@ -1134,7 +1134,7 @@
     return d_ptr->navigationHistory.get();
 }
 
-QDeclarativeComponent* QQuickWebViewExperimental::promptDialog() const
+QQmlComponent* QQuickWebViewExperimental::promptDialog() const
 {
     Q_D(const QQuickWebView);
     return d->promptDialog;
@@ -1148,7 +1148,7 @@
     return d->preferences.get();
 }
 
-void QQuickWebViewExperimental::setPromptDialog(QDeclarativeComponent* promptDialog)
+void QQuickWebViewExperimental::setPromptDialog(QQmlComponent* promptDialog)
 {
     Q_D(QQuickWebView);
     if (d->promptDialog == promptDialog)
@@ -1157,13 +1157,13 @@
     emit promptDialogChanged();
 }
 
-QDeclarativeComponent* QQuickWebViewExperimental::authenticationDialog() const
+QQmlComponent* QQuickWebViewExperimental::authenticationDialog() const
 {
     Q_D(const QQuickWebView);
     return d->authenticationDialog;
 }
 
-void QQuickWebViewExperimental::setAuthenticationDialog(QDeclarativeComponent* authenticationDialog)
+void QQuickWebViewExperimental::setAuthenticationDialog(QQmlComponent* authenticationDialog)
 {
     Q_D(QQuickWebView);
     if (d->authenticationDialog == authenticationDialog)
@@ -1172,13 +1172,13 @@
     emit authenticationDialogChanged();
 }
 
-QDeclarativeComponent* QQuickWebViewExperimental::proxyAuthenticationDialog() const
+QQmlComponent* QQuickWebViewExperimental::proxyAuthenticationDialog() const
 {
     Q_D(const QQuickWebView);
     return d->proxyAuthenticationDialog;
 }
 
-void QQuickWebViewExperimental::setProxyAuthenticationDialog(QDeclarativeComponent* proxyAuthenticationDialog)
+void QQuickWebViewExperimental::setProxyAuthenticationDialog(QQmlComponent* proxyAuthenticationDialog)
 {
     Q_D(QQuickWebView);
     if (d->proxyAuthenticationDialog == proxyAuthenticationDialog)
@@ -1186,13 +1186,13 @@
     d->proxyAuthenticationDialog = proxyAuthenticationDialog;
     emit proxyAuthenticationDialogChanged();
 }
-QDeclarativeComponent* QQuickWebViewExperimental::certificateVerificationDialog() const
+QQmlComponent* QQuickWebViewExperimental::certificateVerificationDialog() const
 {
     Q_D(const QQuickWebView);
     return d->certificateVerificationDialog;
 }
 
-void QQuickWebViewExperimental::setCertificateVerificationDialog(QDeclarativeComponent* certificateVerificationDialog)
+void QQuickWebViewExperimental::setCertificateVerificationDialog(QQmlComponent* certificateVerificationDialog)
 {
     Q_D(QQuickWebView);
     if (d->certificateVerificationDialog == certificateVerificationDialog)
@@ -1201,13 +1201,13 @@
     emit certificateVerificationDialogChanged();
 }
 
-QDeclarativeComponent* QQuickWebViewExperimental::itemSelector() const
+QQmlComponent* QQuickWebViewExperimental::itemSelector() const
 {
     Q_D(const QQuickWebView);
     return d->itemSelector;
 }
 
-void QQuickWebViewExperimental::setItemSelector(QDeclarativeComponent* itemSelector)
+void QQuickWebViewExperimental::setItemSelector(QQmlComponent* itemSelector)
 {
     Q_D(QQuickWebView);
     if (d->itemSelector == itemSelector)
@@ -1216,13 +1216,13 @@
     emit itemSelectorChanged();
 }
 
-QDeclarativeComponent* QQuickWebViewExperimental::filePicker() const
+QQmlComponent* QQuickWebViewExperimental::filePicker() const
 {
     Q_D(const QQuickWebView);
     return d->filePicker;
 }
 
-void QQuickWebViewExperimental::setFilePicker(QDeclarativeComponent* filePicker)
+void QQuickWebViewExperimental::setFilePicker(QQmlComponent* filePicker)
 {
     Q_D(QQuickWebView);
     if (d->filePicker == filePicker)
@@ -1231,13 +1231,13 @@
     emit filePickerChanged();
 }
 
-QDeclarativeComponent* QQuickWebViewExperimental::databaseQuotaDialog() const
+QQmlComponent* QQuickWebViewExperimental::databaseQuotaDialog() const
 {
     Q_D(const QQuickWebView);
     return d->databaseQuotaDialog;
 }
 
-void QQuickWebViewExperimental::setDatabaseQuotaDialog(QDeclarativeComponent* databaseQuotaDialog)
+void QQuickWebViewExperimental::setDatabaseQuotaDialog(QQmlComponent* databaseQuotaDialog)
 {
     Q_D(QQuickWebView);
     if (d->databaseQuotaDialog == databaseQuotaDialog)
@@ -1333,7 +1333,7 @@
     d_ptr->webPageProxy.get()->runJavaScriptInMainFrame(script, ScriptValueCallback::create(closure, _javascript_Callback));
 }
 
-QQuickUrlSchemeDelegate* QQuickWebViewExperimental::schemeDelegates_At(QDeclarativeListProperty<QQuickUrlSchemeDelegate>* property, int index)
+QQuickUrlSchemeDelegate* QQuickWebViewExperimental::schemeDelegates_At(QQmlListProperty<QQuickUrlSchemeDelegate>* property, int index)
 {
     const QObjectList children = property->object->children();
     if (index < children.count())
@@ -1341,7 +1341,7 @@
     return 0;
 }
 
-void QQuickWebViewExperimental::schemeDelegates_Append(QDeclarativeListProperty<QQuickUrlSchemeDelegate>* property, QQuickUrlSchemeDelegate *scheme)
+void QQuickWebViewExperimental::schemeDelegates_Append(QQmlListProperty<QQuickUrlSchemeDelegate>* property, QQuickUrlSchemeDelegate *scheme)
 {
     QObject* schemeParent = property->object;
     scheme->setParent(schemeParent);
@@ -1353,12 +1353,12 @@
     d->webPageProxy->registerApplicationScheme(scheme->scheme());
 }
 
-int QQuickWebViewExperimental::schemeDelegates_Count(QDeclarativeListProperty<QQuickUrlSchemeDelegate>* property)
+int QQuickWebViewExperimental::schemeDelegates_Count(QQmlListProperty<QQuickUrlSchemeDelegate>* property)
 {
     return property->object->children().count();
 }
 
-void QQuickWebViewExperimental::schemeDelegates_Clear(QDeclarativeListProperty<QQuickUrlSchemeDelegate>* property)
+void QQuickWebViewExperimental::schemeDelegates_Clear(QQmlListProperty<QQuickUrlSchemeDelegate>* property)
 {
     const QObjectList children = property->object->children();
     for (int index = 0; index < children.count(); index++) {
@@ -1368,9 +1368,9 @@
     }
 }
 
-QDeclarativeListProperty<QQuickUrlSchemeDelegate> QQuickWebViewExperimental::schemeDelegates()
+QQmlListProperty<QQuickUrlSchemeDelegate> QQuickWebViewExperimental::schemeDelegates()
 {
-    return QDeclarativeListProperty<QQuickUrlSchemeDelegate>(schemeParent, 0,
+    return QQmlListProperty<QQuickUrlSchemeDelegate>(schemeParent, 0,
             QQuickWebViewExperimental::schemeDelegates_Append,
             QQuickWebViewExperimental::schemeDelegates_Count,
             QQuickWebViewExperimental::schemeDelegates_At,

Modified: trunk/Source/WebKit2/UIProcess/API/qt/qquickwebview_p.h (116645 => 116646)


--- trunk/Source/WebKit2/UIProcess/API/qt/qquickwebview_p_p.h	2012-05-10 15:10:11 UTC (rev 116645)
+++ trunk/Source/WebKit2/UIProcess/API/qt/qquickwebview_p_p.h	2012-05-10 15:12:36 UTC (rev 116646)
@@ -51,7 +51,7 @@
 class QWebViewportInfo;
 
 QT_BEGIN_NAMESPACE
-class QDeclarativeComponent;
+class QQmlComponent;
 QT_END_NAMESPACE
 
 class QQuickWebViewPrivate {
@@ -183,15 +183,15 @@
 
     FlickableAxisLocker axisLocker;
 
-    QDeclarativeComponent* alertDialog;
-    QDeclarativeComponent* confirmDialog;
-    QDeclarativeComponent* promptDialog;
-    QDeclarativeComponent* authenticationDialog;
-    QDeclarativeComponent* certificateVerificationDialog;
-    QDeclarativeComponent* itemSelector;
-    QDeclarativeComponent* proxyAuthenticationDialog;
-    QDeclarativeComponent* filePicker;
-    QDeclarativeComponent* databaseQuotaDialog;
+    QQmlComponent* alertDialog;
+    QQmlComponent* confirmDialog;
+    QQmlComponent* promptDialog;
+    QQmlComponent* authenticationDialog;
+    QQmlComponent* certificateVerificationDialog;
+    QQmlComponent* itemSelector;
+    QQmlComponent* proxyAuthenticationDialog;
+    QQmlComponent* filePicker;
+    QQmlComponent* databaseQuotaDialog;
 
     WebCore::ViewportAttributes attributes;
 

Modified: trunk/Source/WebKit2/UIProcess/API/qt/qwebiconimageprovider.cpp (116645 => 116646)


--- trunk/Source/WebKit2/UIProcess/API/qt/qwebiconimageprovider.cpp	2012-05-10 15:10:11 UTC (rev 116645)
+++ trunk/Source/WebKit2/UIProcess/API/qt/qwebiconimageprovider.cpp	2012-05-10 15:12:36 UTC (rev 116646)
@@ -29,7 +29,7 @@
 using namespace WebKit;
 
 QWebIconImageProvider::QWebIconImageProvider()
-    : QDeclarativeImageProvider(QDeclarativeImageProvider::Image)
+    : QQuickImageProvider(QQuickImageProvider::Image)
 {
 }
 

Modified: trunk/Source/WebKit2/UIProcess/API/qt/qwebiconimageprovider_p.h (116645 => 116646)


--- trunk/Source/WebKit2/UIProcess/API/qt/qwebiconimageprovider_p.h	2012-05-10 15:10:11 UTC (rev 116645)
+++ trunk/Source/WebKit2/UIProcess/API/qt/qwebiconimageprovider_p.h	2012-05-10 15:12:36 UTC (rev 116646)
@@ -23,7 +23,7 @@
 #include "qwebkitglobal.h"
 #include <QtQuick/QQuickImageProvider>
 
-class QWEBKIT_EXPORT QWebIconImageProvider : public QDeclarativeImageProvider {
+class QWEBKIT_EXPORT QWebIconImageProvider : public QQuickImageProvider {
 public:
     QWebIconImageProvider();
     ~QWebIconImageProvider();

Modified: trunk/Source/WebKit2/UIProcess/API/qt/qwebviewportinfo_p.h (116645 => 116646)


--- trunk/Source/WebKit2/UIProcess/API/qt/qwebviewportinfo_p.h	2012-05-10 15:10:11 UTC (rev 116645)
+++ trunk/Source/WebKit2/UIProcess/API/qt/qwebviewportinfo_p.h	2012-05-10 15:12:36 UTC (rev 116646)
@@ -27,7 +27,7 @@
 #include <QtCore/QPointer>
 #include <QtCore/QSize>
 #include <QtCore/QVariant>
-#include <QtDeclarative/QtDeclarative>
+#include <QtQml/QtQml>
 
 class QQuickWebViewPrivate;
 

Modified: trunk/Source/WebKit2/UIProcess/API/qt/tests/tests.pri (116645 => 116646)


--- trunk/Source/WebKit2/UIProcess/API/qt/tests/tests.pri	2012-05-10 15:10:11 UTC (rev 116645)
+++ trunk/Source/WebKit2/UIProcess/API/qt/tests/tests.pri	2012-05-10 15:12:36 UTC (rev 116646)
@@ -10,7 +10,7 @@
            ../bytearraytestdata.cpp
 INCLUDEPATH += $$PWD
 
-QT += testlib declarative quick quick-private webkit
+QT += testlib qml quick quick-private webkit
 
 DEFINES += TESTS_SOURCE_DIR=\\\"$$PWD\\\" \
            QWP_PATH=\\\"$${ROOT_BUILD_DIR}/bin\\\"

Modified: trunk/Source/WebKit2/UIProcess/qt/QtDialogRunner.h (116645 => 116646)


--- trunk/Source/WebKit2/UIProcess/qt/QtDialogRunner.h	2012-05-10 15:10:11 UTC (rev 116645)
+++ trunk/Source/WebKit2/UIProcess/qt/QtDialogRunner.h	2012-05-10 15:12:36 UTC (rev 116646)
@@ -27,8 +27,8 @@
 #include <wtf/OwnPtr.h>
 
 QT_BEGIN_NAMESPACE
-class QDeclarativeComponent;
-class QDeclarativeContext;
+class QQmlComponent;
+class QQmlContext;
 class QQuickItem;
 QT_END_NAMESPACE
 
@@ -41,14 +41,14 @@
     QtDialogRunner();
     virtual ~QtDialogRunner();
 
-    bool initForAlert(QDeclarativeComponent*, QQuickItem* dialogParent, const QString& message);
-    bool initForConfirm(QDeclarativeComponent*, QQuickItem* dialogParent, const QString& message);
-    bool initForPrompt(QDeclarativeComponent*, QQuickItem* dialogParent, const QString& message, const QString& defaultValue);
-    bool initForAuthentication(QDeclarativeComponent*, QQuickItem* dialogParent, const QString& hostname, const QString& realm, const QString& prefilledUsername);
-    bool initForCertificateVerification(QDeclarativeComponent*, QQuickItem*, const QString& hostname);
-    bool initForProxyAuthentication(QDeclarativeComponent*, QQuickItem*, const QString& hostname, uint16_t port, const QString& prefilledUsername);
-    bool initForFilePicker(QDeclarativeComponent*, QQuickItem*, const QStringList& selectedFiles, bool allowMultiple);
-    bool initForDatabaseQuotaDialog(QDeclarativeComponent*, QQuickItem*, const QString& databaseName, const QString& displayName, WKSecurityOriginRef, quint64 currentQuota, quint64 currentOriginUsage, quint64 currentDatabaseUsage, quint64 expectedUsage);
+    bool initForAlert(QQmlComponent*, QQuickItem* dialogParent, const QString& message);
+    bool initForConfirm(QQmlComponent*, QQuickItem* dialogParent, const QString& message);
+    bool initForPrompt(QQmlComponent*, QQuickItem* dialogParent, const QString& message, const QString& defaultValue);
+    bool initForAuthentication(QQmlComponent*, QQuickItem* dialogParent, const QString& hostname, const QString& realm, const QString& prefilledUsername);
+    bool initForCertificateVerification(QQmlComponent*, QQuickItem*, const QString& hostname);
+    bool initForProxyAuthentication(QQmlComponent*, QQuickItem*, const QString& hostname, uint16_t port, const QString& prefilledUsername);
+    bool initForFilePicker(QQmlComponent*, QQuickItem*, const QStringList& selectedFiles, bool allowMultiple);
+    bool initForDatabaseQuotaDialog(QQmlComponent*, QQuickItem*, const QString& databaseName, const QString& displayName, WKSecurityOriginRef, quint64 currentQuota, quint64 currentOriginUsage, quint64 currentDatabaseUsage, quint64 expectedUsage);
 
     QQuickItem* dialog() const { return m_dialog.get(); }
 
@@ -88,9 +88,9 @@
     }
 
 private:
-    bool createDialog(QDeclarativeComponent*, QQuickItem* dialogParent, QObject* contextObject);
+    bool createDialog(QQmlComponent*, QQuickItem* dialogParent, QObject* contextObject);
 
-    OwnPtr<QDeclarativeContext> m_dialogContext;
+    OwnPtr<QQmlContext> m_dialogContext;
     OwnPtr<QQuickItem> m_dialog;
     QString m_result;
     bool m_wasAccepted;

Modified: trunk/Source/WebKit2/UIProcess/qt/WebPopupMenuProxyQt.h (116645 => 116646)


--- trunk/Source/WebKit2/UIProcess/qt/WebPopupMenuProxyQt.h	2012-05-10 15:10:11 UTC (rev 116645)
+++ trunk/Source/WebKit2/UIProcess/qt/WebPopupMenuProxyQt.h	2012-05-10 15:12:36 UTC (rev 116646)
@@ -31,8 +31,8 @@
 #include <QtCore/QObject>
 #include <wtf/OwnPtr.h>
 
-class QDeclarativeComponent;
-class QDeclarativeContext;
+class QQmlComponent;
+class QQmlContext;
 class QQuickWebView;
 class QQuickItem;
 
@@ -59,11 +59,11 @@
 private:
     WebPopupMenuProxyQt(WebPopupMenuProxy::Client*, QQuickWebView*);
     void createItem(QObject*);
-    void createContext(QDeclarativeComponent*, QObject*);
+    void createContext(QQmlComponent*, QObject*);
 
     void notifyValueChanged();
 
-    OwnPtr<QDeclarativeContext> m_context;
+    OwnPtr<QQmlContext> m_context;
     OwnPtr<QQuickItem> m_itemSelector;
 
     QQuickWebView* m_webView;
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes

Reply via email to
--- trunk/Source/WebKit2/UIProcess/API/qt/qquickwebview_p.h	2012-05-10 15:10:11 UTC (rev 116645)
+++ trunk/Source/WebKit2/UIProcess/API/qt/qquickwebview_p.h	2012-05-10 15:12:36 UTC (rev 116646)
@@ -28,7 +28,7 @@
 #include <private/qquickflickable_p.h>
 
 class QWebNavigationRequest;
-class QDeclarativeComponent;
+class QQmlComponent;
 class QQuickWebPage;
 class QQuickWebViewAttached;
 class QWebLoadRequest;
@@ -70,7 +70,7 @@
 
 
 // Instantiating the WebView in C++ is only possible by creating
 // a QDeclarativeComponent as the initialization depends on the
 // componentComplete method being called.
 class QWEBKIT_EXPORT QQuickWebView : public QQuickFlickable {
     Q_OBJECT
@@ -253,18 +253,18 @@
     Q_PROPERTY(int preferredMinimumContentsWidth WRITE setPreferredMinimumContentsWidth READ preferredMinimumContentsWidth)
 
     Q_PROPERTY(QWebNavigationHistory* navigationHistory READ navigationHistory CONSTANT FINAL)
-    Q_PROPERTY(QDeclarativeComponent* alertDialog READ alertDialog WRITE setAlertDialog NOTIFY alertDialogChanged)
-    Q_PROPERTY(QDeclarativeComponent* confirmDialog READ confirmDialog WRITE setConfirmDialog NOTIFY confirmDialogChanged)
-    Q_PROPERTY(QDeclarativeComponent* promptDialog READ promptDialog WRITE setPromptDialog NOTIFY promptDialogChanged)
-    Q_PROPERTY(QDeclarativeComponent* authenticationDialog READ authenticationDialog WRITE setAuthenticationDialog NOTIFY authenticationDialogChanged)
-    Q_PROPERTY(QDeclarativeComponent* proxyAuthenticationDialog READ proxyAuthenticationDialog WRITE setProxyAuthenticationDialog NOTIFY proxyAuthenticationDialogChanged)
-    Q_PROPERTY(QDeclarativeComponent* certificateVerificationDialog READ certificateVerificationDialog WRITE setCertificateVerificationDialog NOTIFY certificateVerificationDialogChanged)
-    Q_PROPERTY(QDeclarativeComponent* itemSelector READ itemSelector WRITE setItemSelector NOTIFY itemSelectorChanged)
-    Q_PROPERTY(QDeclarativeComponent* filePicker READ filePicker WRITE setFilePicker NOTIFY filePickerChanged)
-    Q_PROPERTY(QDeclarativeComponent* databaseQuotaDialog READ databaseQuotaDialog WRITE setDatabaseQuotaDialog NOTIFY databaseQuotaDialogChanged)
+    Q_PROPERTY(QQmlComponent* alertDialog READ alertDialog WRITE setAlertDialog NOTIFY alertDialogChanged)
+    Q_PROPERTY(QQmlComponent* confirmDialog READ confirmDialog WRITE setConfirmDialog NOTIFY confirmDialogChanged)
+    Q_PROPERTY(QQmlComponent* promptDialog READ promptDialog WRITE setPromptDialog NOTIFY promptDialogChanged)
+    Q_PROPERTY(QQmlComponent* authenticationDialog READ authenticationDialog WRITE setAuthenticationDialog NOTIFY authenticationDialogChanged)
+    Q_PROPERTY(QQmlComponent* proxyAuthenticationDialog READ proxyAuthenticationDialog WRITE setProxyAuthenticationDialog NOTIFY proxyAuthenticationDialogChanged)
+    Q_PROPERTY(QQmlComponent* certificateVerificationDialog READ certificateVerificationDialog WRITE setCertificateVerificationDialog NOTIFY certificateVerificationDialogChanged)
+    Q_PROPERTY(QQmlComponent* itemSelector READ itemSelector WRITE setItemSelector NOTIFY itemSelectorChanged)
+    Q_PROPERTY(QQmlComponent* filePicker READ filePicker WRITE setFilePicker NOTIFY filePickerChanged)
+    Q_PROPERTY(QQmlComponent* databaseQuotaDialog READ databaseQuotaDialog WRITE setDatabaseQuotaDialog NOTIFY databaseQuotaDialogChanged)
     Q_PROPERTY(QWebPreferences* preferences READ preferences CONSTANT FINAL)
     Q_PROPERTY(QWebViewportInfo* viewportInfo READ viewportInfo CONSTANT FINAL)
-    Q_PROPERTY(QDeclarativeListProperty<QQuickUrlSchemeDelegate> urlSchemeDelegates READ schemeDelegates)
+    Q_PROPERTY(QQmlListProperty<QQuickUrlSchemeDelegate> urlSchemeDelegates READ schemeDelegates)
     Q_PROPERTY(QString userAgent READ userAgent WRITE setUserAgent NOTIFY userAgentChanged)
     Q_PROPERTY(double devicePixelRatio READ devicePixelRatio WRITE setDevicePixelRatio NOTIFY devicePixelRatioChanged)
     Q_ENUMS(NavigationRequestActionExperimental)
@@ -277,24 +277,24 @@
     QQuickWebViewExperimental(QQuickWebView* webView);
     virtual ~QQuickWebViewExperimental();
 
-    QDeclarativeComponent* alertDialog() const;
-    void setAlertDialog(QDeclarativeComponent*);
-    QDeclarativeComponent* confirmDialog() const;
-    void setConfirmDialog(QDeclarativeComponent*);
-    QDeclarativeComponent* promptDialog() const;
-    void setPromptDialog(QDeclarativeComponent*);
-    QDeclarativeComponent* authenticationDialog() const;
-    void setAuthenticationDialog(QDeclarativeComponent*);
-    QDeclarativeComponent* certificateVerificationDialog() const;
-    void setCertificateVerificationDialog(QDeclarativeComponent*);
-    QDeclarativeComponent* itemSelector() const;
-    void setItemSelector(QDeclarativeComponent*);
-    QDeclarativeComponent* proxyAuthenticationDialog() const;
-    void setProxyAuthenticationDialog(QDeclarativeComponent*);
-    QDeclarativeComponent* filePicker() const;
-    void setFilePicker(QDeclarativeComponent*);
-    QDeclarativeComponent* databaseQuotaDialog() const;
-    void setDatabaseQuotaDialog(QDeclarativeComponent*);
+    QQmlComponent* alertDialog() const;
+    void setAlertDialog(QQmlComponent*);
+    QQmlComponent* confirmDialog() const;
+    void setConfirmDialog(QQmlComponent*);
+    QQmlComponent* promptDialog() const;
+    void setPromptDialog(QQmlComponent*);
+    QQmlComponent* authenticationDialog() const;
+    void setAuthenticationDialog(QQmlComponent*);
+    QQmlComponent* certificateVerificationDialog() const;
+    void setCertificateVerificationDialog(QQmlComponent*);
+    QQmlComponent* itemSelector() const;
+    void setItemSelector(QQmlComponent*);
+    QQmlComponent* proxyAuthenticationDialog() const;
+    void setProxyAuthenticationDialog(QQmlComponent*);
+    QQmlComponent* filePicker() const;
+    void setFilePicker(QQmlComponent*);
+    QQmlComponent* databaseQuotaDialog() const;
+    void setDatabaseQuotaDialog(QQmlComponent*);
     QString userAgent() const;
     void setUserAgent(const QString& userAgent);
     double devicePixelRatio() const;
@@ -306,11 +306,11 @@
     QWebNavigationHistory* navigationHistory() const;
     QQuickWebPage* page();
 
-    static QQuickUrlSchemeDelegate* schemeDelegates_At(QDeclarativeListProperty<QQuickUrlSchemeDelegate>*, int index);
-    static void schemeDelegates_Append(QDeclarativeListProperty<QQuickUrlSchemeDelegate>*, QQuickUrlSchemeDelegate*);
-    static int schemeDelegates_Count(QDeclarativeListProperty<QQuickUrlSchemeDelegate>*);
-    static void schemeDelegates_Clear(QDeclarativeListProperty<QQuickUrlSchemeDelegate>*);
-    QDeclarativeListProperty<QQuickUrlSchemeDelegate> schemeDelegates();
+    static QQuickUrlSchemeDelegate* schemeDelegates_At(QQmlListProperty<QQuickUrlSchemeDelegate>*, int index);
+    static void schemeDelegates_Append(QQmlListProperty<QQuickUrlSchemeDelegate>*, QQuickUrlSchemeDelegate*);
+    static int schemeDelegates_Count(QQmlListProperty<QQuickUrlSchemeDelegate>*);
+    static void schemeDelegates_Clear(QQmlListProperty<QQuickUrlSchemeDelegate>*);
+    QQmlListProperty<QQuickUrlSchemeDelegate> schemeDelegates();
     void invokeApplicationSchemeHandler(WTF::PassRefPtr<WebKit::QtRefCountedNetworkRequestData>);
     void sendApplicationSchemeReply(QQuickNetworkReply*);
 
@@ -70,7 +70,7 @@
 
 // Instantiating the WebView in C++ is only possible by creating
-// a QDeclarativeComponent as the initialization depends on the
+// a QQmlComponent as the initialization depends on the
 // componentComplete method being called.
 class QWEBKIT_EXPORT QQuickWebView : public QQuickFlickable {

Modified: trunk/Source/WebKit2/UIProcess/API/qt/qquickwebview_p_p.h (116645 => 116646)

